..
    Use the file automatically generated by dae-devops.
    
.. include:: ../../.dae-devops/docs/installing.rst

Since this package is just a library, the command line doesn't do anything else besides print the version.
To actually run the ePSIC workflows, you'll need to refer to the repository ``dls-bxflow-epsic-workflows`` located on the Diamond intranet.